// Povcal Data Prep

********* LONGEST SPELLS *************
set more off
clear
version 15

import excel "C:\Users\Vanessa\Desktop\Povcal\Datensätze\povcal.xlsx", sheet("Tabelle1") cellrange(A1:M1418) firstrow clear

desc

destring Wattsindex Giniindex, replace force

append using  "C:\Users\Vanessa\Desktop\Povcal\Datensätze\China_India_Indonesia_Povcal_Data.dta"

destring Median MLDindex, replace force

rename MeanMonth MeanInc
rename PovlinePPPday Povline
rename SquaredpovGap SquPovGap
rename Wattsindex Watts
rename Giniindex Gini
rename MLDindex MLD
rename Populationmil Population

label variable Povline "Poverty Line (2011 PPP$/day)"
label variable MeanInc "Mean (2011 PPP$/Month)"
label variable MLD "Mean Log Deviation Index"

notes Datatype: C: grouped consumption
notes Datatype: I: grouped income
notes Datatype: i: unit-record income data with non-parametric analysis
notes Datatype: c: unit-record consumption data with non-parametric analysis

sort Country Year
drop if missing(Country)

// Drop observations for which Gini or Mean Income are missing
foreach var of varlist MeanInc Gini { 
  drop if `var'==. 
  }

// Create ID variable
egen ID = group(Country)
label variable ID "Country ID"
order ID, first


// some countries have income AND consumption data for the same years
duplicates report ID Year
duplicates list ID Year
duplicates tag ID Year, gen(isdup)
gsort + ID + Year + Datatype

// sort by descending alphabetical order to drop consumption data duplicates
// alternatively sort by ascending alphabetical order (change - to +) to drop income data duplicates -> suggested by Ravallion (2012)

duplicates drop ID Year, force

drop isdup


// Add region variable

gen Region = "ECA", after(Country)
replace Region = "LAC" if Country=="Belize" | Country=="Bolivia" | Country=="Brazil" | Country=="Chile" ///
| Country=="Colombia" | Country=="Costa Rica" | Country=="Dominican Republic" | Country=="Ecuador" ///
| Country=="El Salvador" | Country=="Guatemala" | Country=="Guyana" | Country=="Haiti" | Country=="Honduras" ///
| Country=="Jamaica" | Country=="Mexico" | Country=="Nicaragua" | Country=="Panama" | Country=="Paraguay" /// 
| Country=="Peru" | Country=="St. Lucia" | Country=="Suriname" | Country=="Trinidad and Tobago" | Country=="Venezuela, Republica Bolivariana de" ///
| Country=="Uruguay" 

replace Region = "EAP" if Country=="Australia" | Country=="Cambodia" | Country=="China*" | Country=="Fiji" ///
| Country=="Guam" | Country=="Indonesia*" | Country=="Japan" | Country=="Kiribati" | Country=="Korea, Republic of" | Country=="Lao People's Democratic Republic" ///
| Country=="Malaysia" | Country=="Micronesia, Federated States of" | Country=="Mongolia" | Country=="Myanmar" ///
| Country=="Nauru" | Country=="New Zealand" | Country=="Palau" | Country=="Papua New Guinea" | Country=="Philippines" ///
| Country=="Samoa" | Country=="Singapore" | Country=="Solomon Islands" | Country=="Thailand" | Country=="Timor-Leste" | Country=="Tonga" | Country=="Tuvalu" ///
| Country=="Vanuatu" | Country=="Vietnam"  

replace Region = "MENA" if Country=="Algeria" | Country=="Bahrain" | Country=="Djibouti" | Country=="Egypt, Arab Republic of" ///
| Country=="Iran, Islamic Republic of" | Country=="Iraq" | Country=="Israel" | Country=="Jordan" | Country=="Kuwait" | Country=="Lebanon" ///
| Country=="Malta" | Country=="Morocco" | Country=="Oman" | Country=="Qatar" | Country=="Saudi Arabia" | Country=="Syrian Arab Republic" ///
| Country=="Tunisia" | Country=="United Arab Emirates" | Country=="West Bank and Gaza" | Country=="Yemen, Republic of" 

replace Region = "NA" if Country=="Canada" | Country=="Bermuda" | Country=="United States" 

replace Region = "SA" if Country=="Afghanistan" | Country=="Bangladesh" | Country=="Bhutan" | Country=="India*" | Country=="Maldives" ///
| Country=="Nepal" | Country=="Pakistan" | Country=="Sri Lanka" 

replace Region = "SAA" if Country=="Angola" | Country=="Benin" | Country=="Botswana" | Country=="Burkina Faso" | Country=="Burundi" ///
| Country=="Cabo Verde" | Country=="Cameroon" | Country=="Central African Republic" | Country=="Chad" | Country=="Comoros" | Country=="Congo, Democratic Republic of" ///
| Country=="Congo, Republic of" | Country=="Cote d'Ivoire" | Country=="Equatorial Guinea" | Country=="Eritrea" | Country=="Ethiopia" | Country=="Gabon" ///
| Country=="Gambia, The" | Country=="Ghana" | Country=="Guinea" | Country=="Guinea-Bissau" | Country=="Kenya" | Country=="Lesotho" ///
| Country=="Liberia" | Country=="Madagascar" | Country=="Malawi" | Country=="Mali" | Country=="Mauritania" | Country=="Mauritius" ///
| Country=="Mozambique" | Country=="Namibia" | Country=="Niger" | Country=="Nigeria" | Country=="Rwanda" | Country=="Sao Tome and Principe" ///
| Country=="Senegal" | Country=="Seychelles" | Country=="Sierra Leone" | Country=="Somalia" | Country=="South Africa" | Country=="South Sudan" ///
| Country=="Sudan" | Country=="Swaziland" | Country=="Tanzania" | Country=="Togo" | Country=="Uganda" | Country=="Zambia" | Country=="Zimbabwe" 

notes Region: EAP = East Asia & Pacific
notes Region: ECA = Europe & Central Asia
notes Region: LAC = Latin America & Caribbean
notes Region: MENA = Middle East & North Africa
notes Region: NA = North America
notes Region: SA = South Asia
notes Region: SSA = Sub-Saharan Africa
label variable Region "World Bank Region Classification"

// Add Income Classification
joinby Country Year using "C:\Users\Vanessa\Desktop\Povcal\Datensätze\Country_Income_Classification.dta"
notes Classification: L = Low Income
notes Classification: LM = Lower-Middle Income
notes Classification: UM = Upper Middle Income
notes Classification: H = High Income
label variable Classification "Income Classification"

duplicates tag ID Year, gen(isdup)

// some countries have exactly the same data twice

duplicates drop ID Year, force
drop isdup


//No Income classification before 1987 -> use first available value

replace Classification=Classification[_n+1] if Classification==""
replace Classification=Classification[_n+1] if Classification==""
replace Classification=Classification[_n+1] if Classification==""
replace Classification=Classification[_n+1] if Classification==""
replace Classification=Classification[_n+1] if Classification==""
replace Classification=Classification[_n+1] if Classification==""


*********************************

//NEW 2021: include SFI data
joinby Country Year using "C:\Users\Vanessa\Desktop\Povcal\Datensätze\SFI.dta"
drop effect legit sece secl pole poll ecoe ecol soce socl
gen Fragile = 1
replace Fragile=0 if sfi < 15

*********************************

//Drop variables that are not needed
drop PovGap SquPovGap Watts MLD 
*drop countrycode survname datatype coveragetype


//Dummy for consumption/ income data
gen Cons_Inc = 1 
replace Cons_Inc = 0 if Datatype=="I" | Datatype=="i"
label variable Cons_Inc "Consumption (1) or Income (0) Data"

//Dummy for Household/Individual income
gen Hhld_Ind = 0
replace Hhld_Ind = 1 if Datatype=="i" | Datatype=="c"
label variable Hhld_Ind "Household (0) or Individual (1) Data"

drop Datatype

*** Different specification A: drop high-income countries
*drop if Classification=="H"

*** Different specification C: Drop CH, IN, IND
*drop if Country=="China*" | Country=="Indonesia*" | Country=="India*"

//Drop if HC<2
drop if Headcount<2

//Delete observations between first and last year 
by ID, sort : keep if _n == 1 | _n == _N

//Drop if country only has 1 observation
bysort ID: drop if _N==1


***spells minimum 5 years long
sort ID Year
by ID: gen time_diff = Year - Year[_n-1]
sort ID Year
by ID: replace time_diff = time_diff[_n+1] if missing(time_diff)
drop if time_diff < 6

***NEW
//Dummy for fragility in start year 
gen FragileS = Fragile
by ID: replace FragileS = Fragile[_n-1] if FragileS != Fragile[_n-1] 
by ID: replace FragileS = Fragile if missing(FragileS)

drop Fragile

***FRAGILE STATES ONLY
drop if FragileS==1


//*** REGRESSION VARIABLES 

// INEQUALITY

// Log Gini
gen ln_Gini =ln(Gini)
label variable ln_Gini "Log Gini"

// Create lagged Gini variable
sort ID Year 
by ID: gen lag_ln_Gini = ln_Gini[_n-1]
label variable lag_ln_Gini "Lagged Log Gini"

// Create variable for annualized growth of log Gini
sort ID Year
by ID: gen delta_ln_Gini_an = ((ln_Gini - ln_Gini[_n-1])/(Year - Year[_n-1]))
label variable delta_ln_Gini_an "Annual. Change in Gini"


// GROWTH

// Log Mean Income
gen ln_MeanInc =ln(MeanInc)
label variable ln_MeanInc "Log Mean Income"

// Create lagged income variable
sort ID Year 
by ID: gen lag_ln_MeanInc = ln_MeanInc[_n-1]
label variable lag_ln_MeanInc "Lagged Log Mean Income" 

// Create variable for annualized growth of log income 
sort ID Year
by ID: gen delta_ln_MeanInc_an = ((ln_MeanInc - ln_MeanInc[_n-1])/(Year - Year[_n-1]))
label variable delta_ln_MeanInc_an "Annual. Change in Log Mean Income" 

//generate quadratic in lagged log income (for inequality reg)
gen lag_ln_MeanInc_squ = lag_ln_MeanInc^2
label variable lag_ln_MeanInc_squ "Squared Lagged Log Mean Income"


// Growth Regression & Generate Estimate

regress delta_ln_MeanInc_an lag_ln_MeanInc Cons_Inc [iweight=time_diff], robust
gen Estim_delta_ln_MeanInc_an = _b[_cons] + _b[lag_ln_MeanInc]*lag_ln_MeanInc + _b[Cons_Inc]*Cons_Inc 
label variable Estim_delta_ln_MeanInc_an "Estimated Ann. Change in Log Mean Income Growth"

graph twoway (lfit delta_ln_MeanInc_an lag_ln_MeanInc) (scatter delta_ln_MeanInc_an lag_ln_MeanInc)

// Inequality Regression & Generate Estimate

regress delta_ln_Gini_an lag_ln_Gini lag_ln_MeanInc lag_ln_MeanInc_squ Cons_Inc [iweight=time_diff], robust
gen Estim_delta_ln_Gini_an = _b[_cons] + _b[lag_ln_Gini]*lag_ln_Gini + _b[lag_ln_MeanInc]*lag_ln_MeanInc + _b[lag_ln_MeanInc_squ]*lag_ln_MeanInc_squ + _b[Cons_Inc]*Cons_Inc 
test lag_ln_MeanInc lag_ln_MeanInc_squ
label variable Estim_delta_ln_Gini_an "Estimated Ann. Change in Gini Growth"


graph twoway (scatter delta_ln_Gini_an lag_ln_Gini) (lfit delta_ln_Gini_an lag_ln_Gini)


//Store estimates in Word table
eststo: quietly regress  delta_ln_MeanInc_an lag_ln_MeanInc Cons_Inc [iweight=time_diff], robust
esttab using growthtable_SFINF.rtf, r2 replace
eststo clear
eststo: quietly regress delta_ln_Gini_an lag_ln_Gini lag_ln_MeanInc lag_ln_MeanInc_squ Cons_Inc [iweight=time_diff], robust
esttab using inequalitytable_SFINF.rtf, r2 replace
eststo clear


save "C:\Users\Vanessa\Desktop\Povcal\Datensätze\longestspellestimator_SFINF.dta", replace







*****************************************************
********** CONTINUE IN NEW DO-FILE!!! ***************
*****************************************************
** "povertyestimation.do"








