**** POVERTY DECOMPOSITION A LA BOURGUIGNON ***
set more off
clear
version 15

global path  "C:\Users\KMWacker\ownCloud\Documents\Projects\Povertydecomp\Povdecomp_Analysis"

***** From data prep:
use $path\Data\longestspellestimator.dta
 
drop Cons_Inc Hhld_Ind lag_ln_MeanInc_squ delta_ln_MeanInc_an lag_ln_MeanInc ln_MeanInc delta_ln_Gini_an lag_ln_Gini ln_Gini


*** Drop country with HC <2 -> not interesting (Kraay 2006)

drop if Headcount<2
*Drop if country only has 1 observation
bysort ID: drop if _N==1


*** Calculate estimated and actual poverty decomposition (H) using Bourguignon
*Preparation

// GROWTH
// Total Change in Log Mean Inc
sort ID Year
by ID: gen Estim_delta_ln_MeanInc = Estim_delta_ln_MeanInc_an * (Year - Year[_n-1])
label variable Estim_delta_ln_MeanInc "Estimated Total Change in Log Mean Income"

sort ID Year
by ID: gen Estim_MeanInc = exp(Estim_delta_ln_MeanInc) * MeanInc[_n-1] 
label variable Estim_MeanInc "Estimated Mean income for t=1 based on model"


// INEQUALITY
// Total Change in Log Gini
sort ID Year
by ID: gen Estim_delta_ln_Gini = Estim_delta_ln_Gini_an * (Year - Year[_n-1])
label variable Estim_delta_ln_Gini "Estimated Total Change in Log Gini"

sort ID Year
by ID: gen Estim_Gini = exp(Estim_delta_ln_Gini) * Gini[_n-1] 
label variable Estim_Gini "Estimated Gini for t=1 based on model"



******** BOURGUIGNON VARIABLES
*Sigma of Lognormal

gen helpvar = (1 + Gini*0.01)/2

gen sigma_lognormal = sqrt(2) * invnorm(helpvar)

drop helpvar

*inverse development level

gen inv_dev = Povline*30/MeanInc

*time difference

sort ID Year
by ID: replace time_diff = time_diff[_n+1] if missing(time_diff)


****Predicted %-Change in Headcount based on true income and Gini

sort ID Year
by ID: gen helpvar1 = normalden((ln(inv_dev)/sigma_lognormal)+0.5*sigma_lognormal)/normal((ln(inv_dev)/sigma_lognormal)+0.5*sigma_lognormal)

sort ID Year
by ID: gen helpvar2 = (-((ln(MeanInc/MeanInc[_n-1])/time_diff)/sigma_lognormal[_n-1])+(0.5-ln(inv_dev[_n-1])/(sigma_lognormal[_n-1])^2)*((sigma_lognormal-sigma_lognormal[_n-1])/time_diff))

sort ID Year
by ID: gen real_HC = helpvar1[_n-1]*helpvar2
label variable real_HC "Predicted Change in Headcount based on actual income and Gini"

drop helpvar2 



****Expected %-Change in Headcount based on estimated income and Gini

*Estim. Sigma of Lognormal
gen helpvar = (1 + Estim_Gini*0.01)/2
gen estim_sigma_lognormal = sqrt(2) * invnorm(helpvar)
drop helpvar

*Expected %-Change in Headcount
sort ID Year
by ID: gen helpvar2 = (-((ln(Estim_MeanInc/MeanInc[_n-1])/time_diff)/sigma_lognormal[_n-1])+(0.5-ln(inv_dev[_n-1])/(sigma_lognormal[_n-1])^2)*((estim_sigma_lognormal-sigma_lognormal[_n-1])/time_diff))

sort ID Year
by ID: gen estim_HC = helpvar1[_n-1]*helpvar2
label variable estim_HC "Expected Change in Headcount based on estimated income and Gini"

save $path\Data\povertyreductions.dta, replace



****Predicted Contribution of Gini based on true values
sort ID Year
by ID: gen helpvar11 = normalden((ln(inv_dev)/sigma_lognormal)+0.5*sigma_lognormal)/normal((ln(inv_dev)/sigma_lognormal)+0.5*sigma_lognormal)

sort ID Year
by ID: gen helpvar22 = (-((ln(MeanInc[_n-1]/MeanInc[_n-1])/time_diff)/sigma_lognormal[_n-1])+(0.5-ln(inv_dev[_n-1])/(sigma_lognormal[_n-1])^2)*((sigma_lognormal-sigma_lognormal[_n-1])/time_diff))

sort ID Year
by ID: gen real_Gini_contribution = helpvar11[_n-1]*helpvar22
label variable real_Gini_contribution "Predicted Gini contribution based on true data"

drop helpvar22 


****Predicted Contribution of Income based on true values
sort ID Year
by ID: gen helpvar111 = normalden((ln(inv_dev)/sigma_lognormal)+0.5*sigma_lognormal)/normal((ln(inv_dev)/sigma_lognormal)+0.5*sigma_lognormal)

sort ID Year
by ID: gen helpvar222 = (-((ln(MeanInc/MeanInc[_n-1])/time_diff)/sigma_lognormal[_n-1])+(0.5-ln(inv_dev[_n-1])/(sigma_lognormal[_n-1])^2)*((sigma_lognormal[_n-1]-sigma_lognormal[_n-1])/time_diff))

sort ID Year
by ID: gen real_Inc_contribution = helpvar111[_n-1]*helpvar222
label variable real_Inc_contribution "Predicted Income contribution based on true data"

drop helpvar222


****Predicted Contribution of Gini based on estimates
sort ID Year
by ID: gen helpvar22 = (-((ln(MeanInc[_n-1]/MeanInc[_n-1])/time_diff)/sigma_lognormal[_n-1])+(0.5-ln(inv_dev[_n-1])/(sigma_lognormal[_n-1])^2)*((estim_sigma_lognormal-sigma_lognormal[_n-1])/time_diff))

sort ID Year
by ID: gen estim_Gini_contribution = helpvar1[_n-1]*helpvar22
label variable estim_Gini_contribution "Estimated Gini contribution based on esimated values"
drop helpvar22

****Predicted Contribution of Income based on estimates

sort ID Year
by ID: gen helpvar222 = (-((ln(Estim_MeanInc/MeanInc[_n-1])/time_diff)/sigma_lognormal[_n-1])+(0.5-ln(inv_dev[_n-1])/(sigma_lognormal[_n-1])^2)*((sigma_lognormal[_n-1]-sigma_lognormal[_n-1])/time_diff))

sort ID Year
by ID: gen estim_Inc_contribution = helpvar1[_n-1]*helpvar222
label variable estim_Inc_contribution "Estimated Income contribution based on esimated values"

drop helpvar222 helpvar11 Estim_delta_ln_Gini Estim_delta_ln_MeanInc_an Estim_delta_ln_Gini_an Estim_delta_ln_MeanInc

drop helpvar111 helpvar2 helpvar1 inv_dev sigma_lognormal estim_sigma_lognormal 

save $path\Data\povertyreductions.dta, replace


***********************************************
****NEW: Bourgignon Approximation

*1. zuerst sigma1 aus ginit1 erzeugen -- sigma ist die std.deviation von lognormal incomes; 1 steht für periode 1, gini ist NICHT in logs. Gleiches für Periode 2.
*gen sigma = invnormal(((Gini/100)+1)/2) * sqrt(2)

*by ID: gen dsigma = (sigma[_N]-sigma[_n-1])/time_diff

*2. Angenommen meant1 und meant2 sind mean income am Beginn und Ende (nicht in logs!), dann können wir Bourguignon-Approximation erzeugen mit:

*by ID: gen gh2_theory = (normalden((log((2*365)/ (MeanInc[_n-1]*12))/sigma[_n-1]) + 0.5*sigma[_n-1])) / (normal((log((2*365)/ (MeanInc[_n-1]*12))/sigma[_n-1]) + 0.5*sigma[_n-1])) * ((-1)*((log(MeanInc[_N]/MeanInc[_n-1])/time_diff)/sigma[_n-1]) + (0.5 - log((2*365)/ (MeanInc[_n-1]*12))/(sigma[_n-1]*sigma[_n-1]))*(dsigma[_N]))
*label variable gh2_theory "Bourguignon Approximation"

*3. Wenn gh2 log changes in poverty headcount ratio sind, dann müssen wir diese nurmehr auf die eben berechnete Approximation regressieren:
// Log HC
*gen ln_Headcount =ln(Headcount)
*label variable ln_Headcount "Log Headcount"

// Create lagged HC variable
*sort ID Year 
*by ID: gen lag_ln_Headcount = ln_Headcount[_n-1]
*label variable lag_ln_Headcount "Lagged Log HC"

// Create variable for annualized growth of log HC
*sort ID Year
*by ID: gen delta_ln_HC_an = ((ln_Headcount - ln_Headcount[_n-1])/(Year - Year[_n-1]))
*label variable delta_ln_HC_an "Annual. Log Change in Headcount"

*reg delta_ln_HC_an gh2_theory, robust

*twoway scatter delta_ln_HC_an gh2_theory || lfit  delta_ln_HC_an gh2_theory
*corr  delta_ln_HC_an gh2_theory

//Store estimates in Word table
*eststo: quietly regress  delta_ln_HC_an gh2_theory, robust
*esttab using bourgignon.rtf, r2 replace
*eststo clear

************************************************ 


*****

drop ID Year Region MeanInc Povline Headcount Gini Median Population Classification time_diff estim_HC real_HC Estim_Gini Estim_MeanInc
drop if missing( real_Gini_contribution)



***SCATTERPLOTS***
replace Country = "Congo, Dem. Rep" if Country == "Congo, Democratic Republic of"
replace Country = "Congo, Rep." if Country == "Congo, Republic of"
replace Country = "Central African Rep." if Country == "Central African Republic"
replace Country = "Egypt, Arab Rep." if Country == "Egypt, Arab Republic of"
replace Country = "Iran, Islamic Rep." if Country == "Iran, Islamic Republic of"
replace Country = "Korea, Rep." if Country == "Korea, Republic of"
replace Country = "Lao PDR" if Country == "Lao People's Democratic Republic"
replace Country = "Macedonia" if Country == "Macedonia, former Yugoslav Republic of"
replace Country = "Micronesia, Fed. States" if Country == "Micronesia, Federated States of"
replace Country = "Venezuela, RB" if Country =="Venezuela, Republica Bolivariana de"
replace Country = "China" if Country=="China*"
replace Country = "Indonesia" if Country=="Indonesia*"
replace Country = "India" if Country=="India*"

gen real_contr1 = real_Gini_contribution*100
gen real_contr2 = real_Inc_contribution*100
gen expected_contr1 = estim_Gini_contribution*100
gen expected_contr2 = estim_Inc_contribution*100

label variable real_contr1 "Gini contribution (%) based on actual values"
label variable real_contr2 "Income contribution (%) based on actual values"
label variable expected_contr1 "Estimated Gini contribution (%) based on esimated values"
label variable expected_contr2 "Estimated Income contribution (%) based on esimated values"

drop real_Gini_contribution real_Inc_contribution estim_Gini_contribution estim_Inc_contribution

reshape long real_contr expected_contr, i(Country) j(source)
label variable source "Gini=1, Inc=2"
label define source 1 "Redistribution" 2 "Income Growth" 

rename real_contr contr1
rename expected_contr contr2

egen group = group(Country source)
reshape long contr, i(group) j(actual_expected)
drop group
label variable actual_expected "actual=1, expected=2"
label define actual_expected 1 "T" 2 "E"
label variable contr "Contribution to Headcount Reduction"
label values actual_expected actual_expected
label values source source


graph bar (sum) contr in 1/144 , over(source) over( actual_expected, gap(*0.1) label(labsize(vsmall) angle(horizontal))) over(Country, label(labsize(small) angle(stdarrow)) gap(*0.3)) bar(1, fcolor(cranberry) lcolor("0 0 0 %0")) bar(2, fcolor(navy)lcolor("0 0 0 %0")) ytitle("%-Contribution to Headcount Change", size(small)) asyvars outergap(0.5) stack scheme(sj) ylabel(#10, labels labsize(vsmall)) xsize(9) ysize(3) legend(size(small)) yscale(range(-15 10))  
graph save Graph $path\Figures\HCContributions1-36.gph, replace
graph export $path\Figures\HCContributions1-36.png, as(png) replace

/* For consistent survey methodology: */
label define actual_expected 1 "HC2" 2 "HC3", replace
gen barorder = 0
replace barorder = 1 if Country=="Brazil"
replace barorder = 2 if Country=="Chad"
replace barorder = 3 if Country=="Lao PDR"
replace barorder = 4 if Country=="Ethiopia"
replace barorder = 5 if Country=="Mexico"
replace barorder = 6 if Country=="Iraq"
replace barorder = 7 if Country=="Belize"
graph bar (sum) contr if Country=="Brazil" | Country=="Chad" | Country=="Lao PDR"| Country=="Ethiopia" | Country=="Mexico", over(source) over(actual_expected, gap(*0.05) label(labsize(medsmall) angle(horizontal))) over(Country, sort(barorder) label(labsize(medlarge) angle(horizontal)) gap(*0.2)) bar(1, fcolor(cranberry) lcolor("0 0 0 %0")) bar(2, fcolor(navy)lcolor("0 0 0 %0")) ytitle("%-Contribution to Headcount Change", size(normal)) asyvars outergap(0.5) stack scheme(sj) ylabel(#6, labels labsize(small)) xsize(9) ysize(3) legend(size(normal)) yscale(range(-6 2)) graphregion(color(white))

sdf

graph bar (sum) contr in 145/284, over(source) over( actual_expected, gap(*0.1) label(labsize(vsmall) angle(horizontal))) over(Country, label(labsize(small) angle(stdarrow)) gap(*0.3)) bar(1, fcolor(cranberry) lcolor("0 0 0 %0")) bar(2, fcolor(navy)lcolor("0 0 0 %0")) ytitle("%-Contribution to Headcount Change", size(small)) asyvars outergap(0.5) stack scheme(sj) ylabel(#10, labels labsize(vsmall)) xsize(9) ysize(3) legend(size(small)) yscale(range(-15 10))  caption(T = Contribution to HC reduction calculated with true data (HC2); E = Contribution to HC reduction calculated with estimates (HC3), size(small))
graph save Graph $path\Figures\HCContributions37-71.gph, replace
graph export $path\Figures\HCContributions37-71.png, as(png) replace

save $path\Data\graphdata.dta, replace


***TOTAL CONTRIBUTION
** (a) Alphabetical order
clear
use $path\Data\povertyreductions.dta

replace Country = "Congo, Dem. Rep" if Country == "Congo, Democratic Republic of"
replace Country = "Congo, Rep." if Country == "Congo, Republic of"
replace Country = "Central African Rep." if Country == "Central African Republic"
replace Country = "Egypt, Arab Rep." if Country == "Egypt, Arab Republic of"
replace Country = "Iran, Islamic Rep." if Country == "Iran, Islamic Republic of"
replace Country = "Korea, Rep." if Country == "Korea, Republic of"
replace Country = "Lao PDR" if Country == "Lao People's Democratic Republic"
replace Country = "Macedonia" if Country == "Macedonia, former Yugoslav Republic of"
replace Country = "Micronesia, Fed. States" if Country == "Micronesia, Federated States of"
replace Country = "Venezuela, RB" if Country =="Venezuela, Republica Bolivariana de"
replace Country = "China" if Country=="China*"
replace Country = "Indonesia" if Country=="Indonesia*"
replace Country = "India" if Country=="India*"

drop Year Region ID MeanInc Povline Headcount Gini Median Population Classification time_diff Estim_MeanInc Estim_Gini
gen real_HC_perc = real_HC*100
gen estim_HC_perc = estim_HC *100
drop estim_Inc_contribution estim_Gini_contribution real_Inc_contribution real_Gini_contribution estim_HC real_HC
drop if missing(real_HC_perc)
label variable real_HC_perc "True Data (HC2)"
label variable estim_HC_perc "Estimates (HC3)"

graph bar (asis) real_HC_perc estim_HC_perc in 1/36, over(Country, label(angle(stdarrow) labsize(small))) bar(1, fcolor(green) lcolor("0 0 0 %0")) bar(2, fcolor(midgreen) lcolor("0 0 0 %0")) bargap(1) blabel(total, size(vsmall) format(%-4.1f)) ytitle(Total %-Headcount Change) ylabel(-15(5)10) legend(size(small)) scheme(sj) xsize(9) ysize(3)
graph save Graph $path\Figures\TotalHCContributions1-36.gph, replace
graph export $path\Figures\TotalHCContributions1-36.png, as(png) replace

graph bar (asis) real_HC_perc estim_HC_perc in 37/71, over(Country, label(angle(stdarrow) labsize(small))) bar(1, fcolor(green) lcolor("0 0 0 %0")) bar(2, fcolor(midgreen) lcolor("0 0 0 %0")) bargap(1) blabel(total, size(vsmall) format(%-4.1f)) ytitle(Total %-Headcount Change) ylabel(-15(5)10) legend(size(small)) scheme(sj) xsize(9) ysize(3)
graph save Graph $path\Figures\TotalHCContributions37-71.gph, replace
graph export $path\Figures\TotalHCContributions37-71.png, as(png) replace

**(b) Different scales
sort estim_HC_perc
graph bar (asis) real_HC_perc estim_HC_perc in 1/36, over(Country, sort(real_HC_perc) label(angle(stdarrow) labsize(vsmall))) bar(1, fcolor(green) lcolor("0 0 0 %0")) bar(2, fcolor(midgreen) lcolor("0 0 0 %0")) bargap(0.1) blabel(total, size(vsmall) format(%5.1g)) ytitle(Total % HC Reduction) ylabel(-10(5)10) caption(Act.=Actual Contribution to HC Reduction; Est.=Estimated Contribution to HC Reduction, size(vsmall)) legend(size(small)) scheme(sj) xsize(10) ysize(3)
graph save Graph $path\Figures\TotalHCContributions1-36diffscale.gph, replace
graph export $path\Figures\TotalHCContributions1-36diffscale.png, as(png) replace

graph bar (asis) real_HC_perc estim_HC_perc in 37/71, over(Country, sort(real_HC_perc) label(angle(stdarrow) labsize(vsmall))) bar(1, fcolor(green) lcolor("0 0 0 %0")) bar(2, fcolor(midgreen) lcolor("0 0 0 %0")) bargap(0.1) blabel(total, size(vsmall) format(%5.1g)) ytitle(Total % HC Reduction) ylabel(-20(10)10) caption(Act.=Actual Contribution to HC Reduction; Est.=Estimated Contribution to HC Reduction, size(vsmall)) legend(size(small)) scheme(sj) xsize(10) ysize(3)
graph save Graph $path\Figures\TotalHCContributions37-71diffscale.gph, replace
graph export $path\Figures\TotalHCContributions37-71diffscale.png, as(png) replace

save $path\Data\totalcontrgraphdata.dta, replace


***Growth/Inequality IN DESCENDING ORDER (different scales)
clear
use $path\Data\graphdata.dta
merge m:m Country using $path\Data\totalcontrgraphdata.dta 
drop _merge

bysort Country: replace real_HC_perc=real_HC_perc[_n+1] if missing(real_HC_perc)
bysort Country: replace estim_HC_perc=estim_HC_perc[_n+1] if missing(estim_HC_perc)
sort estim_HC_perc

graph bar (sum) contr in 1/144, over(source) over( actual_expected, gap(*0.1) label(labsize(tiny) angle(horizontal))) over(Country, sort(estim_HC_perc) label(labsize(vsmall) angle(stdarrow)) gap(*0.3)) bar(1, fcolor(cranberry) lcolor("0 0 0 %0")) bar(2, fcolor(navy)lcolor("0 0 0 %0")) ytitle("%-Contribution to HC Reduction", size(small)) asyvars outergap(0.5) stack scheme(sj) ylabel(#10, labels labsize(vsmall)) xsize(10) ysize(3) legend(size(small)) yscale(range(-10 10))  caption(Act.=Actual Contribution to HC Reduction; Est.=Estimated Contribution to HC Reduction, size(vsmall))
graph save Graph $path\Figures\HCContributions1-36diffscale.gph, replace
graph export $path\Figures\HCContributions1-36diffscale.png, as(png) replace

graph bar (sum) contr in 145/284, over(source) over( actual_expected, gap(*0.1) label(labsize(tiny) angle(horizontal))) over(Country, sort(estim_HC_perc) label(labsize(vsmall) angle(stdarrow)) gap(*0.3)) bar(1, fcolor(cranberry) lcolor("0 0 0 %0")) bar(2, fcolor(navy)lcolor("0 0 0 %0")) ytitle("%-Contribution to HC Reduction", size(small)) asyvars outergap(0.5) stack scheme(sj) ylabel(#10, labels labsize(vsmall)) xsize(10) ysize(3) legend(size(small)) yscale(range(-10 10))  caption(Act.=Actual Contribution to HC Reduction; Est.=Estimated Contribution to HC Reduction, size(vsmall))
graph save Graph $path\Figures\HCContributions37-71diffscale.gph, replace
graph export $path\Figures\HCContributions37-71diffscale.png, as(png) replace





*** PREDICTED VS ACTUAL
**(a) TOTAL REDUCTION
clear
use $path\Data\totalcontrgraphdata.dta

twoway scatter real_HC_perc estim_HC_perc || lfit real_HC_perc estim_HC_perc
corr real_HC_perc estim_HC_perc


** (b) Individual contributions
clear
use $path\Data\povertyreductions.dta

*GINI
twoway scatter real_Gini_contribution estim_Gini_contribution || lfit real_Gini_contribution estim_Gini_contribution
corr real_Gini_contribution estim_Gini_contribution

twoway scatter Gini Estim_Gini || lfit Gini Estim_Gini
corr Gini Estim_Gini


*Income
twoway scatter real_Inc_contribution estim_Inc_contribution || lfit real_Inc_contribution estim_Inc_contribution
corr real_Inc_contribution estim_Inc_contribution

twoway scatter MeanInc Estim_MeanInc || lfit MeanInc Estim_MeanInc
corr MeanInc Estim_MeanInc


* Official Headcount and estimate

gen Estim_Headcount = Headcount[_n-1] * (1 + estim_HC)^(time_diff)
label variable Estim_Headcount "Estimated Headcount (absolute value)"

twoway scatter Headcount Estim_Headcount|| lfit Headcount Estim_Headcount
corr Headcount Estim_Headcount

*Estimated and true Bourguignon HC

gen Real_Headcount = Headcount[_n-1] * (1 + real_HC)^(time_diff)
label variable Real_Headcount "Real Headcount (absolute value)"

twoway scatter Estim_Headcount Real_Headcount|| lfit Estim_Headcount Real_Headcount
corr Estim_Headcount Real_Headcount



***NEW

***STRONGEST NOMINAL DEVIATIONS
*1) TOTAL REDUCTION 
clear
use $path\Data\totalcontrgraphdata.dta

gen NomDiffRedPredTotal = real_HC_perc-estim_HC_perc
label variable NomDiffRedPredTotal "Nominal difference btw. expected and real poverty reduction"
sort NomDiffRedPredTotal
summarize NomDiff
sum2docx NomDiff using summarystatsdeviations.docx, replace stats(N mean(%9.2f) sd min(%9.0g) max(%9.0g) median(%9.0g) )


*2) Individual contributions
clear
use $path\Data\graphdata.dta
merge m:m Country using $path\Data\totalcontrgraphdata.dta
drop _merge

*GINI
drop real_HC_perc estim_HC_perc
drop if source==2

reshape wide contr, i(Country) j(actual_expected)
label variable contr1 "True Contribution"
label variable contr2 "Expected Contribution"
gen NomDiffRedPredGini = contr1-contr2
sort NomDiffRedPredGini
summarize NomDiff
sum2docx NomDiff using summarystatsdeviationsGini.docx, replace stats(N mean(%9.2f) sd min(%9.0g) max(%9.0g) median(%9.0g) )

*Income
clear
use $path\Data\graphdata.dta
merge m:m Country using $path\Data\totalcontrgraphdata.dta
drop _merge

drop real_HC_perc estim_HC_perc
drop if source==1

reshape wide contr, i(Country) j(actual_expected)
label variable contr1 "True Contribution"
label variable contr2 "Expected Contribution"
gen NomDiffRedPredInc = contr1-contr2
sort NomDiffRedPredInc
summarize NomDiff
sum2docx NomDiff using $path\summarystatsdeviationsInc.docx, replace stats(N mean(%9.2f) sd min(%9.0g) max(%9.0g) median(%9.0g) )


